/*
 * crypto_enums.h
 *
 *  Created on: Oct 1, 2019
 *      Author: yves
 */

#ifndef SHARED_CRYPTO_ENUMS_H_
#define SHARED_CRYPTO_ENUMS_H_

#ifdef __cplusplus
#include <stdint.h>

namespace Hsm {

enum e_signOperation : uint32_t {
#else
typedef enum   {
#endif
   sign = 0,
   signEkaIntegrity,
   signAttestation,
   signTimestamp,
#ifdef __cplusplus
};
#else
} e_signOperation;
#endif

#ifdef __cplusplus
enum e_algorithms : uint32_t {
#else
typedef enum   {
#endif
   algRsa = 0,
   algDsa,
   algDh,
   algAes,
   algCamellia,
   algSha224,
   algSha256,
   algSha384,
   algSha512,
   algSha1,
   algTdea,
   algSha3224,
   algSha3256,
   algSha3384,
   algSha3512,
   algEc,
   algMd5,
   algDhx942,
   algHmacMd5,
   algHmacSha1,
   algHmacSha224,
   algHmacSha256,
   algHmacSha384,
   algHmacSha512,
   algHmacSha3224,
   algHmacSha3256,
   algHmacSha3384,
   algHmacSha3512,
   algEdDsa,
   algRipEmd160,
   algHmacRipEmd160,
   algRsaEka,
   algDsaEka,
   algEcEka,
   algEdDsaEka,
   algKeccak224,
   algKeccak256,
   algKeccak384,
   algKeccak512,
   algKerl,
   algIss,
   algIssEka,
   algEcCkd,
   algEcCkdEka,
   algRsaRks,
   algChaCha20,
   algPoly1305,
   algDhParams,
   algDhx942Params,
   algDsaParams,
   algEcRks,
   NumOfAlgorithms,
   lastAlgorithm = algEcRks,
   algNotSpecified = 0xFFFFFFFE //Use -2 since -1 is bad for JCE.
#ifdef __cplusplus
};
#else
} e_algorithms;
#endif

#ifdef __cplusplus
enum e_mgmtConfigValue : uint32_t {
#else
typedef enum   {
#endif
   configMgmtInvalid = 0,
   configMgmtProtocolJce,
   configMgmtProtocolPkcs,
   configMgmtProtocolCng,
   configMgmtProtocolMgmt,
   configMgmtSetupPasswordLifetime,
   configMgmtUserReadOnly,
   configMgmtAllowKeyImport,
   configMgmtAllowKeyExport,
   configMgmtCloneReadOnly,
   configMgmtEkaOnMaster,
   configMgmtKeyInvalidation,
   configMgmtPkcsUserPassword,
   configMgmtCryptoAccess,
   configMgmtSoAccess,
   configMgmtMaxUserSize,
   configMgmtAllowKeyExtract,
   configMgmtExternalStorage,
   lastConfigValue = configMgmtAllowKeyExtract,
#ifdef __cplusplus
};
#else
} e_mgmtConfigValue;
#endif

#ifdef __cplusplus
enum e_objType : uint32_t {
#else
typedef enum   {
#endif
   typeNotSpecified = 0,
   typePrivateKey,
   typePublicKey,
   typeSecretKey,
   typeUserCredentials,
   typeCertificate,
   typeKeyPair,
   typeDataObject,
   typeEkaPrivateKey,
   typeEkaKeyPair,
   typeRksPrivateKey,
   typeRksKeyPair,
   typeKeyStoreInfo,
   typeExternal = 0x01000000, // Used internally for logs only. Using will result in error
   typeExternalPrivateKey,
   typeExternalEkaPrivateKey,
   typeExternalRksPrivateKey,
   typeExternalSecretKey,
#ifdef __cplusplus
};
#else
} e_objType;
#endif

#ifdef __cplusplus
enum Crypto_method : uint32_t {
#else
typedef enum   {
#endif
   metRsaNoneSha2Pss224 = 0,
   metRsaNoneSha2Pss256,
   metRsaNoneSha2Pss384,
   metRsaNoneSha2Pss512,
   metRsaSha2Pss224,
   metRsaSha2Pss256,
   metRsaSha2Pss384,
   metRsaSha2Pss512,
   metDsaNone,
   metDsaSha2224,
   metDsaSha2256,
   metDsaSha2384,
   metDsaSha2512,
   metRsaPkcsNone,
   metRsaSha2Pkcs224,
   metRsaSha2Pkcs256,
   metRsaSha2Pkcs384,
   metRsaSha2Pkcs512,
   metRsaSha2Oaep224,
   metRsaSha2Oaep256,
   metRsaSha2Oaep384,
   metRsaSha2Oaep512,
   metAesCbcPadded,
   metCamelliaCbcPadded,
   metAesGcm,
   metAesCtr,
   metAesEcb,
   metCamelliaEcb,
   metAesKeyWrapPad,
   metTdeaEcb,
   metTdeaCbcPadded,
   metRsaNoneSha1Pss160,
   metRsaNoneSha3Pss224,
   metRsaNoneSha3Pss256,
   metRsaNoneSha3Pss384,
   metRsaNoneSha3Pss512,
   metRsaSha1Pss160,
   metRsaSha3Pss224,
   metRsaSha3Pss256,
   metRsaSha3Pss384,
   metRsaSha3Pss512,
   metDsaSha1160,
   metDsaSha3224,
   metDsaSha3256,
   metDsaSha3384,
   metDsaSha3512,
   metRsaSha1Pkcs160,
   metRsaSha3Pkcs224,
   metRsaSha3Pkcs256,
   metRsaSha3Pkcs384,
   metRsaSha3Pkcs512,
   metRsaSha1Oaep160,
   metRsaSha3Oaep224,
   metRsaSha3Oaep256,
   metRsaSha3Oaep384,
   metRsaSha3Oaep512,
   metSha1160Hmac,
   metSha2224Hmac,
   metSha2256Hmac,
   metSha2384Hmac,
   metSha2512Hmac,
   metSha3224Hmac,
   metSha3256Hmac,
   metSha3384Hmac,
   metSha3512Hmac,
   metDlDh,
   metEcDsaNone,
   metEcDhNone,
   metRsaNone,
   metRsaNoneSha1Pkcs160,
   metRsaNoneSha2Pkcs224,
   metRsaNoneSha2Pkcs256,
   metRsaNoneSha2Pkcs384,
   metRsaNoneSha2Pkcs512,
   metRsaNoneSha3Pkcs224,
   metRsaNoneSha3Pkcs256,
   metRsaNoneSha3Pkcs384,
   metRsaNoneSha3Pkcs512,
   metEcDsaSha1160,
   metEcDsaSha2224,
   metEcDsaSha2256,
   metEcDsaSha2384,
   metEcDsaSha2512,
   metEcDsaSha3224,
   metEcDsaSha3256,
   metEcDsaSha3384,
   metEcDsaSha3512,
   metMd5Hmac,
   metRsaMd5Pkcs,
   metRsaNoneMd5Pkcs,
   metCamelliaCtr,
   metCamelliaGcm,
   metAesMac,
   metAesCmac,
   metAesGmac,
   metCamelliaMac,
   metCamelliaCmac,
   metCamelliaGmac,
   metAesKeyWrap,
   metDlDhx942None,
   metDlDhx942Sha1,
   metEcDhSha1,
   metEcDhSha224,
   metEcDhSha256,
   metEcDhSha384,
   metEcDhSha512,
   metAesCbc,
   metCamelliaCbc,
   metTdeaCbc,
   metKdfCtrCmacAes,
   metKdfCtrHmacSha1,
   metKdfCtrHmacSha224,
   metKdfCtrHmacSha256,
   metKdfCtrHmacSha384,
   metKdfCtrHmacSha512,
   metKdfFeedbackCmacAes,
   metKdfFeedbackHmacSha1,
   metKdfFeedbackHmacSha224,
   metKdfFeedbackHmacSha256,
   metKdfFeedbackHmacSha384,
   metKdfFeedbackHmacSha512,
   metKdfPipelineCmacAes,
   metKdfPipelineHmacSha1,
   metKdfPipelineHmacSha224,
   metKdfPipelineHmacSha256,
   metKdfPipelineHmacSha384,
   metKdfPipelineHmacSha512,
   metEdDsa,
   metRipEmd160Hmac,
   metRsaRipEmdPkcs160,
   metEcDsaKeccak224,
   metEcDsaKeccak256,
   metEcDsaKeccak384,
   metEcDsaKeccak512,
   metTdeaCmac,
   metDlDhx942Sha224,
   metDlDhx942Sha256,
   metDlDhx942Sha384,
   metDlDhx942Sha512,
   metKdfSha1,
   metKdfSha224,
   metKdfSha256,
   metKdfSha384,
   metKdfSha512,
   metKdfHmacSha1,
   metKdfHmacSha224,
   metKdfHmacSha256,
   metKdfHmacSha384,
   metKdfHmacSha512,
   metTlsPrf,
   metIssKerl,
   metEcPrivateCkd,
   metEcPublicCkd,
   metCkdHmac,
   metKdf2Sha1,
   metKdf2Sha224,
   metKdf2Sha256,
   metKdf2Sha384,
   metKdf2Sha512,
   metChaCha20,
   metPoly1305,
   metChaCha20Poly1305,
   metPbk2Sha1Pkcs12,
   metPbkdf2Sha224,
   metPbkdf2Sha256,
   metPbkdf2Sha384,
   metPbkdf2Sha512,
   metPbkdf2Sha1,
   numOfMethods,
   lastMethod = metPbkdf2Sha1,
   metNotSpecified = 0xFFFFFFFE, //Use -2 since -1 is bad for JCE.
   metRsaDummy = metNotSpecified - 1,
   metDsaDummy = metNotSpecified - 2,
   metEcDsaDummy = metNotSpecified - 3
#ifdef __cplusplus
};
#else
} e_method;
#endif

#ifdef __cplusplus
enum e_fieldId : uint32_t {
#else
typedef enum   {
#endif
   fieldInvalid = 0x0,
   fieldId = 0x1,
   fieldSubject = 0x2,
   fieldIssuer = 0x3,
   fieldStartDate = 0x4,
   fieldEndDate = 0x5,
   fieldApplication = 0x6,
   fieldObjectId = 0x7,
   fieldModulus = 0x8,
   fieldPublicExponent = 0x9,
   fieldKeyCredentials = 0xA,
   fieldCkdChainCode = 0xB,
   fieldEcParams = 0xC,
   fieldPrime = 0xD,
   fieldSubPrime = 0xE,
   fieldBase = 0xF,
   fieldCertificateChain = 0x10,
   fieldCryptoCurrency = 0x11,
   fieldMax = 0xFF,
#ifdef PRIMUS_TEE
   fieldLocalhost = 0x800
#else
   fieldCng = 0x100,
   fieldPkcs = 0x200,
   fieldJce = 0x400
#endif
#ifdef __cplusplus
};
#else
} e_fieldId;
#endif

#ifdef __cplusplus
enum e_currency : uint32_t {
#else
typedef enum   {
#endif
   cryptoCurrencyNotSpecified = 0,
   cryptoCurrencyBitcoin,
   cryptoCurrencyEthereum,
   cryptoCurrencyStellar,
   cryptoCurrencyIota,
   cryptoCurrencyRipple,
#ifdef __cplusplus
};
#else
} e_currency;
#endif

}

#endif /* SHARED_CRYPTO_ENUMS_H_ */
